# nina
Erhalten Sie wichtige Warnmeldungen des Bevölkerungsschutzes für Gefahrenlagen wie zum Beispiel Gefahrstoffausbreitung oder Unwetter per Programmierschnittstelle.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://warnung.bund.de/](https://warnung.bund.de/)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

```sh
pip install deutschland[nina]
```

### poetry install

```sh
poetry add deutschland -E nina
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

## Usage

Import the package:
```python
from deutschland import nina
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
from deutschland import nina
from pprint import pprint
from deutschland.nina.api import archive_api
from deutschland.nina.model.archive_warning_history import ArchiveWarningHistory
from deutschland.nina.model.warning import Warning
# Defining the host is optional and defaults to https://warnung.bund.de/api31
# See configuration.py for a list of all supported configuration parameters.
configuration = nina.Configuration(
    host = "https://warnung.bund.de/api31"
)



# Enter a context with an instance of the API client
with nina.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = archive_api.ArchiveApi(api_client)
    identifier = "mow.DE-NI-OL-W015-20230121-002" # str | Meldungs-ID

    try:
        # Gesammelter Verlauf einer MOWAS Warnung
        api_response = api_instance.get_full_warning_history(identifier)
        pprint(api_response)
    except nina.ApiException as e:
        print("Exception when calling ArchiveApi->get_full_warning_history: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://warnung.bund.de/api31*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArchiveApi* | [**get_full_warning_history**](docs/ArchiveApi.md#get_full_warning_history) | **GET** /archive.mowas/{identifier}-mapping.json | Gesammelter Verlauf einer MOWAS Warnung
*ArchiveApi* | [**get_warning_history**](docs/ArchiveApi.md#get_warning_history) | **GET** /archive.mowas/{identifier}.json | Abruf einer archivierten MOWAS Warnung
*CovidApi* | [**get_ars_covid_rules**](docs/CovidApi.md#get_ars_covid_rules) | **GET** /appdata/covid/covidrules/DE/{ARS}.json | Corona Regelungen nach ARS
*CovidApi* | [**get_covid_infos**](docs/CovidApi.md#get_covid_infos) | **GET** /appdata/covid/covidinfos/DE/covidinfos.json | Allgemeine Informationen zu Corona
*CovidApi* | [**get_covid_map**](docs/CovidApi.md#get_covid_map) | **GET** /appdata/covid/covidmap/DE/covidmap.json | Kartendaten für Corona-Fallzahlen.
*CovidApi* | [**get_covid_ticker**](docs/CovidApi.md#get_covid_ticker) | **GET** /appdata/covid/covidticker/DE/covidticker.json | Covid-Ticker
*CovidApi* | [**get_covid_ticker_message**](docs/CovidApi.md#get_covid_ticker_message) | **GET** /appdata/covid/covidticker/DE/tickermeldungen/{id}.json | Detailinformationen zu Covid-Ticker Meldungen
*WarningsApi* | [**get_biwapp_map_data**](docs/WarningsApi.md#get_biwapp_map_data) | **GET** /biwapp/mapData.json | Biwapp Meldungen
*WarningsApi* | [**get_dashboard**](docs/WarningsApi.md#get_dashboard) | **GET** /dashboard/{ARS}.json | Meldungsübersicht nach ARS
*WarningsApi* | [**get_dwd_map_data**](docs/WarningsApi.md#get_dwd_map_data) | **GET** /dwd/mapData.json | Unwetterwarnungen des Deutschen Wetterdienstes
*WarningsApi* | [**get_katwarn_map_data**](docs/WarningsApi.md#get_katwarn_map_data) | **GET** /katwarn/mapData.json | Katwarn Meldungen
*WarningsApi* | [**get_lhp_map_data**](docs/WarningsApi.md#get_lhp_map_data) | **GET** /lhp/mapData.json | Meldungen des Länderübergreifenden Hochwasserportals
*WarningsApi* | [**get_mowas_map_data**](docs/WarningsApi.md#get_mowas_map_data) | **GET** /mowas/mapData.json | Mowas Meldungen
*WarningsApi* | [**get_police_map_data**](docs/WarningsApi.md#get_police_map_data) | **GET** /police/mapData.json | Polizeimeldungen
*WarningsApi* | [**get_warning**](docs/WarningsApi.md#get_warning) | **GET** /warnings/{identifier}.json | Detailinformation zu einer Warnung
*WarningsApi* | [**get_warning_geo_json**](docs/WarningsApi.md#get_warning_geo_json) | **GET** /warnings/{identifier}.geojson | GeoJSON informationen zu einer Warnung.
*DefaultApi* | [**get_data_version**](docs/DefaultApi.md#get_data_version) | **GET** /dynamic/version/dataVersion.json | Liefert die Versionsnummer.
*DefaultApi* | [**get_event_code**](docs/DefaultApi.md#get_event_code) | **GET** /appdata/gsb/eventCodes/{filename} | Event Code Bilddateien.
*DefaultApi* | [**get_event_codes**](docs/DefaultApi.md#get_event_codes) | **GET** /appdata/gsb/eventCodes/eventCodes.json | Liefert Event Codes und Name der Bilddateien.
*DefaultApi* | [**get_faqs**](docs/DefaultApi.md#get_faqs) | **GET** /appdata/gsb/faqs/DE/faq.json | FAQs
*DefaultApi* | [**get_logo**](docs/DefaultApi.md#get_logo) | **GET** /appdata/gsb/logos/{filename} | Logo-Bilddateien.
*DefaultApi* | [**get_logos**](docs/DefaultApi.md#get_logos) | **GET** /appdata/gsb/logos/logos.json | Liefert Namen und Logos für Sender-IDs
*DefaultApi* | [**get_notfalltipps**](docs/DefaultApi.md#get_notfalltipps) | **GET** /appdata/gsb/notfalltipps/DE/notfalltipps.json | Notfalltipps


## Documentation For Models

 - [ARSCovidRules](docs/ARSCovidRules.md)
 - [ARSCovidRulesCommonInner](docs/ARSCovidRulesCommonInner.md)
 - [ARSCovidRulesLevel](docs/ARSCovidRulesLevel.md)
 - [ARSCovidRulesRegulations](docs/ARSCovidRulesRegulations.md)
 - [ARSCovidRulesRegulationsSections](docs/ARSCovidRulesRegulationsSections.md)
 - [ARSCovidRulesRegulationsSectionsBUND](docs/ARSCovidRulesRegulationsSectionsBUND.md)
 - [ARSCovidRulesRegulationsSectionsBUNDIcon](docs/ARSCovidRulesRegulationsSectionsBUNDIcon.md)
 - [ARSCovidRulesRegulationsSectionsKREIS](docs/ARSCovidRulesRegulationsSectionsKREIS.md)
 - [ARSCovidRulesRegulationsSectionsKREISIcon](docs/ARSCovidRulesRegulationsSectionsKREISIcon.md)
 - [ARSCovidRulesRegulationsSectionsLAND](docs/ARSCovidRulesRegulationsSectionsLAND.md)
 - [ARSCovidRulesRegulationsSectionsLANDIcon](docs/ARSCovidRulesRegulationsSectionsLANDIcon.md)
 - [ARSCovidRulesRulesInner](docs/ARSCovidRulesRulesInner.md)
 - [ARSCovidRulesRulesInnerIcon](docs/ARSCovidRulesRulesInnerIcon.md)
 - [ARSOverviewResult](docs/ARSOverviewResult.md)
 - [ARSOverviewResultInner](docs/ARSOverviewResultInner.md)
 - [ARSOverviewResultInnerI18nTitle](docs/ARSOverviewResultInnerI18nTitle.md)
 - [ARSOverviewResultInnerPayload](docs/ARSOverviewResultInnerPayload.md)
 - [ARSOverviewResultInnerPayloadData](docs/ARSOverviewResultInnerPayloadData.md)
 - [ARSOverviewResultInnerPayloadDataArea](docs/ARSOverviewResultInnerPayloadDataArea.md)
 - [ARSOverviewResultInnerPayloadDataTransKeys](docs/ARSOverviewResultInnerPayloadDataTransKeys.md)
 - [ArchiveWarningHistory](docs/ArchiveWarningHistory.md)
 - [ArchiveWarningHistoryHistoryInner](docs/ArchiveWarningHistoryHistoryInner.md)
 - [CovidInfos](docs/CovidInfos.md)
 - [CovidInfosArticle](docs/CovidInfosArticle.md)
 - [CovidInfosCategory](docs/CovidInfosCategory.md)
 - [CovidInfosImage](docs/CovidInfosImage.md)
 - [CovidInfosTip](docs/CovidInfosTip.md)
 - [CovidMap](docs/CovidMap.md)
 - [CovidMapData](docs/CovidMapData.md)
 - [CovidMapLegend](docs/CovidMapLegend.md)
 - [CovidMapStyle](docs/CovidMapStyle.md)
 - [CovidTicker](docs/CovidTicker.md)
 - [CovidTickerEntry](docs/CovidTickerEntry.md)
 - [CovidTickerMessage](docs/CovidTickerMessage.md)
 - [EventCode](docs/EventCode.md)
 - [EventCodeCollection](docs/EventCodeCollection.md)
 - [FAQ](docs/FAQ.md)
 - [FAQCollection](docs/FAQCollection.md)
 - [KeyValueArray](docs/KeyValueArray.md)
 - [KeyValueArrayInner](docs/KeyValueArrayInner.md)
 - [Logo](docs/Logo.md)
 - [LogoCollection](docs/LogoCollection.md)
 - [MapWarnings](docs/MapWarnings.md)
 - [MapWarningsInner](docs/MapWarningsInner.md)
 - [MapWarningsInnerI18nTitle](docs/MapWarningsInnerI18nTitle.md)
 - [Notfalltipps](docs/Notfalltipps.md)
 - [NotfalltippsArticle](docs/NotfalltippsArticle.md)
 - [NotfalltippsCategory](docs/NotfalltippsCategory.md)
 - [NotfalltippsCollection](docs/NotfalltippsCollection.md)
 - [NotfalltippsImage](docs/NotfalltippsImage.md)
 - [NotfalltippsTip](docs/NotfalltippsTip.md)
 - [Version](docs/Version.md)
 - [VersionCollection](docs/VersionCollection.md)
 - [Warning](docs/Warning.md)
 - [WarningInfoInner](docs/WarningInfoInner.md)
 - [WarningInfoInnerAreaInner](docs/WarningInfoInnerAreaInner.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

kontakt@bund.dev


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in nina.apis and nina.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from deutschland.nina.api.default_api import DefaultApi`
- `from deutschland.nina.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
from deutschland import nina
from deutschland.nina.apis import *
from deutschland.nina.models import *
```

